fix_INCLUDING_ON_PURPOSE {#master}
------------------------

## Libraries

### `dev`

* The `IVisualParams.h` file was deprecated in favour of `IRgbVisualParams.h`
  and `IDepthVisualParams`.
* All headers for the deprecated interfaces are now properly deprecated.
